# mypy-boto3-autoscaling

Mypy-friendly auto-generated type annotations for `boto3 autoscaling 1.10.39` service.
More information can be found [here](https://github.com/vemel/mypy_boto3).

- [mypy-boto3-autoscaling](#mypy-boto3-autoscaling)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
    - [Code auto-complete](#code-auto-complete)
  - [How it works](#how-it-works)

## How to use

### Type checking

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `autoscaling` service.

```bash
python -m pip install boto3-stubs[mypy-boto3-autoscaling]
```

Use `boto3` with `mypy_boto3` in your project and enjoy type checking.

```python
import boto3

from mypy_boto3 import autoscaling
# alternative import if you do not want to install mypy_boto3 package
# import mypy_boto3_autoscaling as autoscaling

# Use this client as usual, now mypy can check if your code is valid.
# Check if your IDE supports function overloads,
# you probably do not need explicit type annotations
# client = boto3.client("autoscaling")
client: autoscaling.AutoScalingClient = boto3.client("autoscaling")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: autoscaling.AutoScalingClient = session.client("autoscaling")


# Paginators need type annotation on creation
describe_auto_scaling_groups_paginator: autoscaling.DescribeAutoScalingGroupsPaginator = client.get_paginator("describe_auto_scaling_groups")
describe_auto_scaling_instances_paginator: autoscaling.DescribeAutoScalingInstancesPaginator = client.get_paginator("describe_auto_scaling_instances")
describe_launch_configurations_paginator: autoscaling.DescribeLaunchConfigurationsPaginator = client.get_paginator("describe_launch_configurations")
describe_load_balancer_target_groups_paginator: autoscaling.DescribeLoadBalancerTargetGroupsPaginator = client.get_paginator("describe_load_balancer_target_groups")
describe_load_balancers_paginator: autoscaling.DescribeLoadBalancersPaginator = client.get_paginator("describe_load_balancers")
describe_notification_configurations_paginator: autoscaling.DescribeNotificationConfigurationsPaginator = client.get_paginator("describe_notification_configurations")
describe_policies_paginator: autoscaling.DescribePoliciesPaginator = client.get_paginator("describe_policies")
describe_scaling_activities_paginator: autoscaling.DescribeScalingActivitiesPaginator = client.get_paginator("describe_scaling_activities")
describe_scheduled_actions_paginator: autoscaling.DescribeScheduledActionsPaginator = client.get_paginator("describe_scheduled_actions")
describe_tags_paginator: autoscaling.DescribeTagsPaginator = client.get_paginator("describe_tags")
```

## How it works

Fully automated [builder](https://github.com/vemel/mypy_boto3) carefully generates
type annotations for each service, patiently waiting for `boto3` updates. It delivers
a drop-in type annotations for you and makes sure that:

- Latest version of `boto3` is used.
- Each public class and method of every `boto3` service gets valid type annotations
  extracted from latest documentation (blame `botocore` docs if types are incorrect).
- Type annotations include up-to-date documentation.
- Code is processed by [black](https://github.com/psf/black) for readability.